@@ -1,5 +1,5 @@
 /*
- * AutoGen Globally exported prototypes Sat Oct 27 11:49:54 PDT 2001
+ * AutoGen Globally exported prototypes Sat Dec  1 20:58:46 PST 2001
  */
 #ifndef AUTOGEN_PROTOTYPES_H
 #define AUTOGEN_PROTOTYPES_H
@@ -142,8 +142,6 @@ loadTemplate( tCC* pzFileName );
 
 /* exports from tpParse.c */
 
-tCC*
-skipMacro( tCC* pzStartMark );
 tMacro*
 parseTemplate( tTemplate* pT, tMacro* pM, tCC** ppzText );
 
