@@ -1,13 +1,13 @@
 /*  -*- Mode: C -*-
  *
- *  $Id: getdefs.h,v 2.7 2001/08/23 03:23:50 bkorb Exp $
+ *  $Id: getdefs.h,v 2.9 2001/12/01 18:02:47 bkorb Exp $
  *
  *    getdefs copyright 1999 Bruce Korb
  *
  *  Author:            Bruce Korb <bkorb@gnu.org>
  *  Maintainer:        Bruce Korb <bkorb@gnu.org>
  *  Created:           Mon Jun 30 15:35:12 1997
- *  Last Modified:     $Date: 2001/08/23 03:23:50 $
+ *  Last Modified:     $Date: 2001/12/01 18:02:47 $
  *            by:      Bruce Korb <bkorb@gnu.org>
  */
 
@@ -42,6 +42,13 @@
 #  include <regex.h>
 #endif
 
+#ifdef DEBUG
+#  define STATIC
+#else
+#  define STATIC static
+#endif
+#define EXPORT
+
 #include "opts.h"
 
 #ifdef DEFINE
@@ -86,6 +93,10 @@
 #  define STR(s)    __STR(s)
 #endif
 
+#define AG_NAME_CHAR(c) (zUserNameCh[(unsigned)(c)] & 2)
+#define USER_NAME_CH(c) (zUserNameCh[(unsigned)(c)] & 1)
+MODE char zUserNameCh[ 256 ] VALUE( { '\0' } );
+
 /*
  *  Procedure success codes
  *
@@ -175,4 +186,6 @@ MODE size_t  blkAllocCt VALUE(  0 );
 
 MODE pid_t   agPid      VALUE( -1 );
 
+#include "proto.h"
+
 #endif /* GETDEFS_HEADER */
